cordex.regions.\_germany.Germany
================================

.. currentmodule:: cordex.regions._germany

.. autoclass:: Germany

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Germany.__init__
      ~Germany.geodataframe
      ~Germany.regionmask
   
   

   
   
   